@@ -140,7 +140,7 @@ icc <- function(x, ...) {
 
 #' @importFrom lme4 VarCorr fixef getME
 #' @importFrom glmmTMB VarCorr fixef getME
-#' @importFrom stats family formula sigma
+#' @importFrom stats family formula
 #' @importFrom purrr map map_dbl map_lgl
 icc.lme4 <- function(fit, obj.name) {
   # check object class
@@ -172,6 +172,9 @@ icc.lme4 <- function(fit, obj.name) {
     # random slope-variances (tau 11)
     tau.11 <- unlist(lapply(reva, function(x) diag(x)[-1]))
 
+    # get residual standard deviation sigma
+    sig <- attr(reva, "sc")
+
     # residual variances, i.e.
     # within-cluster-variance (sigma^2)
     if (inherits(fit, c("glmerMod", "glmmTMB")) && fitfam == "binomial") {
@@ -179,10 +182,13 @@ icc.lme4 <- function(fit, obj.name) {
       resid_var <- (pi ^ 2) / 3
     } else if (inherits(fit, "glmerMod") && is_negbin) {
       # for negative binomial models, we use 0
-      resid_var <- 0
+      resid_var <- 1
     } else {
       # for linear and poisson models, we have a clear residual variance
-      resid_var <- stats::sigma(fit) ^ 2
+      resid_var <- sig ^ 2
+
+      # requires R >= 3.3
+      # resid_var <- stats::sigma(fit) ^ 2
     }
 
     # total variance, sum of random intercept and residual variances
@@ -199,7 +205,10 @@ icc.lme4 <- function(fit, obj.name) {
         # for negative binomial models, we also need the intercept...
         beta <- as.numeric(glmmTMB::fixef(fit)[[1]]["(Intercept)"])
         # ... and the theta value to compute the ICC
-        r <- stats::sigma(fit)
+        r <- sig
+
+        # requires R >= 3.3
+        # r <- stats::sigma(fit)
       }
 
       # make formula more readable
@@ -269,7 +278,7 @@ icc.lme4 <- function(fit, obj.name) {
 #' @param comp Name of the variance component to be returned. See 'Details'.
 #'
 #' @return \code{get_re_var()} returns the value of the requested variance component,
-#'           \code{re_var()} returns \code{NULL}.
+#'           \code{re_var()} returns all random effects variances.
 #'
 #' @references Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490–1528 (\doi{10.1177/0149206313478188})
 #'
@@ -284,6 +293,11 @@ icc.lme4 <- function(fit, obj.name) {
 #'          \item{\code{"tau.01"}}{Random-Intercept-Slope-covariance}
 #'          \item{\code{"rho.01"}}{Random-Intercept-Slope-correlation}
 #'         }
+#'         The within-group-variance is affected by factors at level one, i.e.
+#'         by the lower-level direct effects. Level two factors (i.e. cross-level
+#'         direct effects) affect the between-group-variance. Cross-level
+#'         interaction effects are group-level factors that explain the
+#'         variance in random slopes (Aguinis et al. 2013).
 #'
 #' @seealso \code{\link{icc}}
 #'
@@ -302,11 +316,25 @@ icc.lme4 <- function(fit, obj.name) {
 #' re_var(fit2)
 #'
 #' @importFrom stats family
+#' @importFrom purrr map map2 flatten_dbl flatten_chr
+#' @importFrom sjmisc trim
 #' @export
 re_var <- function(x) {
   # return value
   revar_ <- icc(x)
-  print(revar_, comp = "var")
+
+  # iterate all attributes and return them as vector
+  rv <- c("sigma_2", "tau.00", "tau.11", "tau.01", "rho.01")
+
+  rv_ <- purrr::map(rv, ~ attr(revar_, .x, exact = TRUE))
+  rn <- purrr::map2(1:length(rv_), rv, ~ sjmisc::trim(paste(names(rv_[[.x]]), .y, sep = "_")))
+  rv_ <- purrr::flatten_dbl(rv_)
+
+  names(rv_) <- purrr::flatten_chr(rn)
+
+  class(rv_) <- c("sj_revar", class(rv_))
+
+  rv_
 }
 
 
